/*
* This file is part of Bielefeld Sensor Actuator Interface (BonSAI).
*
* Copyright(c) Frederic Siepmann
* http://opensource.cit-ec.de/projects/bonsai
*
* This file may be licensed under the terms of of the
* GNU Lesser General Public License Version 3 (the ``LGPL''),
* or (at your option) any later version.
*
* Software distributed under the License is distributed
* on an ``AS IS'' basis, WITHOUT WARRANTY OF ANY KIND, either
* express or implied. See the LGPL for the specific language
* governing rights and limitations.
*
* You should have received a copy of the LGPL along with this
* program. If not, go to http://www.gnu.org/licenses/lgpl.html
* or write to the Free Software Foundation, Inc.,
* 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
*
* The development of this software was supported by the
* Excellence Cluster EXC 277 Cognitive Interaction Technology.
* The Excellence Cluster EXC 277 is a grant of the Deutsche
* Forschungsgemeinschaft (DFG) in the context of the German
* Excellence Initiative.
*
* Contributors: Leon Ziegler, Johannes Wienke, Norman Köster, Torben Töniges,
*               Annika Rothert, Alexander Baumann, Marcel Dulisch, Maikel Linke,
*               Marian Pohling, Lukas Twardon, Lukas Kettenbach
*/
package de.unibi.airobots.bonsai.actuators;

import de.unibi.airobots.bonsai.core.Actuator;
import de.unibi.airobots.btl.data.navigation.GoalReachedData;
import de.unibi.airobots.btl.data.navigation.NavigationGoalData;
import java.io.IOException;

/**
 * Base interface for all actuators that control the robots pose.
 * 
 * @author jwienke
 */
public interface NavigationActuator extends Actuator {

    /**
     * Sets a new goal to move to.
     * 
     * @param data
     *            new goal
     * @throws IOException
     *             communication error
     */
    void setGoal(NavigationGoalData data) throws IOException;

    /**
     * Check whether the last set goal was reached.
     * 
     * @return encapsulation of reached answer
     * @throws IOException
     *             communication error
     */
    GoalReachedData isGoalReached() throws IOException;

    /**
     * Manually stop the robot as fast as possible.
     * 
     * @throws IOException
     *             communication error
     */
    void manualStop() throws IOException;

    /**
     * Getter for the current navigation goal.
     * 
     * @return An instance of {@link NavigationGoalData} representing the
     *         current goal of the navigation algorithm.
     * @throws IOException
     *             communication error
     */
    NavigationGoalData getCurrentGoal() throws IOException;

}
