package de.unibi.airobots.bonsai.util.arm.calibration;

import java.io.File;
import java.io.IOException;

import org.apache.log4j.BasicConfigurator;
import org.apache.log4j.Logger;

import de.unibi.airobots.bonsai.actuators.PoseActuatorTobi;
import de.unibi.airobots.bonsai.core.BonsaiManager;
import de.unibi.airobots.bonsai.core.Sensor;
import de.unibi.airobots.bonsai.core.BonsaiManager.ConfigurationException;
import de.unibi.airobots.bonsai.core.SensorListener;
import de.unibi.airobots.bonsai.xcf.actuators.XcfPoseActuatorTobi;
import de.unibi.airobots.btl.data.geometry.Point3D;
import de.unibi.airobots.btl.data.grasp.KatanaPoseData;
import de.unibi.airobots.btl.units.LengthUnit;
import de.unibi.airobots.bonsai.util.arm.ArmController;

public class CalibrationTest implements SensorListener<Point3D> {

	private static TestOptions options;
	public Sensor<Point3D> chessboardSensor;
	public PoseActuatorTobi poseActuatorTobi;
	private ArmController ac;

	public CalibrationTest(File bonsaiConfig) {
		try {
			BonsaiManager.getInstance().configure(bonsaiConfig.toURI());
		} catch (IllegalStateException e) {
			System.err.println("Error initializing BonSAI!");
			Logger.getRootLogger().error("Error initializing BonSAI!");
			Logger.getRootLogger().debug(e);
			System.exit(1);
		} catch (ConfigurationException e) {
			System.err.println("Error initializing BonSAI!");
			Logger.getRootLogger().error("Error initializing BonSAI!");
			Logger.getRootLogger().debug(e);
			System.exit(1);
		}
		
		chessboardSensor = BonsaiManager.getInstance().createSensor("ChessboardSensor", Point3D.class);
		chessboardSensor.addSensorListener(this);

		ac = new ArmController(poseActuatorTobi);
		
		//ac.goTo(new Point3D(-171.7232818603516, 20.84188079833984, 750.000061035156, LengthUnit.MILLIMETER));
		//ac.readSensors();
		//ac.goOut();
		//doFollowRoutine();
		//doFrontalGraspRoutine();
		//doGraspRoutine();
		System.err.println(ac.adjustCurrentPosition(0, 0, 10));
	}

	/**
	 * A simple follow routine that lets the arm 
	 * continuously follow the calibration tool.
	 */
	private void doFollowRoutine() {
		while(true) {
			try {
				Point3D kinect = chessboardSensor.readLast();
				ac.goTo(kinect);
			} catch (IOException e) {
				// TODO Auto-generated catch block
				e.printStackTrace();
			} catch (InterruptedException e) {
				// TODO Auto-generated catch block
				e.printStackTrace();
			}
		}
	}
	
	/**
	 * A simple grasping routine that lets the arm
	 * continuously grasp the position of the calibration tool.
	 */
	private void doGraspRoutine() {
		try {
			this.poseActuatorTobi.setMovements("grasp_down_init_close");
		} catch (IOException e1) {
			System.err.println("Error while going to grasp position:");
			e1.printStackTrace();
		}
		this.ac.waitAfterMovement();
		while(true) {
			try {
				Point3D kinect = chessboardSensor.readLast();
				ac.grasp(kinect);
				ac.openGripper();
				ac.goInit();
			} catch (IOException e) {
				// TODO Auto-generated catch block
				e.printStackTrace();
			} catch (InterruptedException e) {
				// TODO Auto-generated catch block
				e.printStackTrace();
			}
		}
	}
	
	/**
	 * A simple grasping routine that lets the arm
	 * continuously grasp the position of the calibration tool frontally.
	 */
	private void doFrontalGraspRoutine() {
		try {
			this.poseActuatorTobi.setMovements("grasp_down_init_close");
		} catch (IOException e1) {
			System.err.println("Error while going to grasp position:");
			e1.printStackTrace();
		}
		this.ac.waitAfterMovement();
		while(true) {
			try {
				Point3D kinect = chessboardSensor.readLast();
				ac.graspFrontally(kinect);
				ac.openGripper();
				ac.waitAfterMovement();
				ac.adjustCurrentPosition(0, 0, -80);
				ac.waitAfterMovement();
				ac.goInit();
				ac.waitAfterMovement();
			} catch (IOException e) {
				// TODO Auto-generated catch block
				e.printStackTrace();
			} catch (InterruptedException e) {
				// TODO Auto-generated catch block
				e.printStackTrace();
			}
		}
	}

	public static void main(String[] args) {
		BasicConfigurator.configure();
//		
//		// parse command line options
//		options = new TestOptions();
//		CmdLineParser parser = new CmdLineParser(options);
//		try {
//			parser.parseArgument(args);
//		} catch (CmdLineException e) {
//			System.err.println(e.getMessage());
//			System.err.println();
//			System.err.println("java CalibrationTest [options...]");
//			parser.printUsage(System.err);
//			System.exit(1);
//		}
//
//		// show help?
//		if (options.help) {
//			System.out.println("java CalibrationTest [options...]");
//			parser.printUsage(System.out);
//			System.exit(0);
//		}
//		
//		// start program
//		try {
//			Logger.getRootLogger().info("CalibrationTest started");
//			@SuppressWarnings("unused")
//			CalibrationTest control = new CalibrationTest(options.bonsaiConfig);
//
//		} catch (Exception e) {
//			Logger.getRootLogger().error(
//					"CalibrationTest threw an exception. \n\nError: ", e);
//		}
	}

	@Override
	public void newDataAvailable(Point3D newData) {
		// TODO Auto-generated method stub
		
	}

}
