/*
 * This file is part of Bielefeld Sensor Actuator Interface (BonSAI).
 *
 * Copyright(c) Frederic Siepmann
 * http://opensource.cit-ec.de/projects/bonsai
 *
 * This file may be licensed under the terms of of the
 * GNU Lesser General Public License Version 3 (the ``LGPL''),
 * or (at your option) any later version.
 *
 * Software distributed under the License is distributed
 * on an ``AS IS'' basis, WITHOUT WARRANTY OF ANY KIND, either
 * express or implied. See the LGPL for the specific language
 * governing rights and limitations.
 *
 * You should have received a copy of the LGPL along with this
 * program. If not, go to http://www.gnu.org/licenses/lgpl.html
 * or write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 *
 * The development of this software was supported by the
 * Excellence Cluster EXC 277 Cognitive Interaction Technology.
 * The Excellence Cluster EXC 277 is a grant of the Deutsche
 * Forschungsgemeinschaft (DFG) in the context of the German
 * Excellence Initiative.
 *
 * Contributors: Leon Ziegler, Johannes Wienke, Norman Köster, Torben Töniges,
 *               Annika Rothert, Alexander Baumann, Marcel Dulisch, Maikel Linke,
 *               Marian Pohling, Lukas Twardon, Lukas Kettenbach
 */
package de.unibi.airobots.bonsai.util.helper.annotation;

import de.unibi.airobots.btl.Type;


/**
 * 
 * @author jhelbach
 */
public class MapPoint extends Type {

	private double x;
	
	private double y;
	
	private MapPoint.Kind kind;
	
	private MapPoint.Unit unit;
	
	private String ref;
	
	
	public MapPoint(double x, double y) {
		this.x = x;
		this.y = y;
		ref = "";
		kind = Kind.WORLD;
		unit = Unit.M;
	}
	
	public MapPoint(double x, double y, Kind kind, Unit unit, String ref) {
		super();
		this.x = x;
		this.y = y;
		this.kind = kind;
		this.unit = unit;
		this.ref = ref;
	}

	
	public MapPoint(MapPoint p) {
		this.x = p.getX();
		this.y = p.getY();
		this.kind = p.getKind();
		this.unit = p.getUnit();
		this.ref = p.getRef();
	}

	public double getX() {
		return x;
	}

	public void setX(double x) {
		this.x = x;
	}

	public double getY() {
		return y;
	}

	public void setY(double y) {
		this.y = y;
	}

	public MapPoint.Kind getKind() {
		return kind;
	}

	public void setKind(MapPoint.Kind kind) {
		this.kind = kind;
	}

	public MapPoint.Unit getUnit() {
		return unit;
	}

	public void setUnit(MapPoint.Unit unit) {
		this.unit = unit;
	}

	public String getRef() {
		return ref;
	}

	public void setRef(String ref) {
		this.ref = ref;
	}

	public enum Unit {
		M, 
		CM, 
		MM,
		NM
	}

	public enum Kind {
		WORLD, 
		RELATIVE
	}
	
}
